"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SSOService = void 0;
const Base_1 = require("./Base");
const exceptions_1 = require("./exceptions");
class SSOService extends Base_1.Base {
    /**
     * Get SSO details
     *
     */
    async getSSOByBusinessHandle(handle) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/sso?handle=${handle}`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.get(url), {
            404: () => new exceptions_1.NotFoundException("SSO not found"),
        });
        return json;
    }
    /**
     * Get OIDC SSO configuration
     *
     */
    async getRemoteOIODCConfiguration(remoteOidcConfigUrl) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/sso/configuration?url=${remoteOidcConfigUrl}`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.get(url), {
            404: () => new exceptions_1.NotFoundException("SSO not found"),
        });
        return json;
    }
    /**
     * Get SSO provider connection link
     *
     */
    async getSSOProviderConnectionLink(providerAlias, clientId) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/sso/account-link?provider=${providerAlias}&clientId=${clientId}`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.get(url), {
            404: () => new exceptions_1.NotFoundException("SSO provider found"),
            403: (error) => new exceptions_1.ForbiddenException(error === null || error === void 0 ? void 0 : error.body.message),
            401: (error) => new exceptions_1.ForbiddenException(error === null || error === void 0 ? void 0 : error.body.message),
            422: () => new exceptions_1.UnprocessableEntityException(`Failed to retrieve link for provider ${providerAlias}`),
        });
        return json;
    }
}
exports.SSOService = SSOService;
